package nonreg.simple;

public class A0002_TestResult {
}
/*
"""
DPI: 96
dimension: [ 763.0498 ; 890.5000 ]
scaleFactor: 1.0000
seed: -9181376250803721714
svgLinkTarget: _top
hoverPathColorRGB: null
preserveAspectRatio: none

ELLIPSE:
  pt1: [ 170.9019 ; 35.5000 ]
  pt2: [ 190.9019 ; 55.5000 ]
  start: 0.0
  extend: 0.0
  stroke: 0.0-0.0-1.0
  shadow: 0
  color: ff222222
  backcolor: ff222222

EMPTY:
  pt1: [ 20.0000 ; 220.0000 ]
  pt2: [ 143.4243 ; 289.0000 ]

PATH:
   - type: SEG_MOVETO
     pt1: [ 0.0000 ; 0.0000 ]
   - type: SEG_LINETO
     pt1: [ 0.0000 ; 49.0000 ]
   - type: SEG_LINETO
     pt1: [ 103.4243 ; 49.0000 ]
   - type: SEG_LINETO
     pt1: [ 103.4243 ; 10.0000 ]
   - type: SEG_LINETO
     pt1: [ 93.4243 ; 0.0000 ]
   - type: SEG_LINETO
     pt1: [ 0.0000 ; 0.0000 ]
  stroke: 0.0-0.0-0.5
  shadow: 0
  color: ff181818
  backcolor: fffeffdd

PATH:
   - type: SEG_MOVETO
     pt1: [ 93.4243 ; 0.0000 ]
   - type: SEG_LINETO
     pt1: [ 93.4243 ; 10.0000 ]
   - type: SEG_LINETO
     pt1: [ 103.4243 ; 10.0000 ]
   - type: SEG_LINETO
     pt1: [ 93.4243 ; 0.0000 ]
  stroke: 0.0-0.0-0.5
  shadow: 0
  color: ff181818
  backcolor: fffeffdd

TEXT:
  text: This 
  position: [ 36.0000 ; 245.1111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: is a 
  position: [ 36.0000 ; 258.1111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: note
  position: [ 36.0000 ; 271.1111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

EMPTY:
  pt1: [ 218.3794 ; 65.5000 ]
  pt2: [ 441.7562 ; 443.5000 ]

PATH:
   - type: SEG_MOVETO
     pt1: [ 0.0000 ; 0.0000 ]
   - type: SEG_LINETO
     pt1: [ 0.0000 ; 358.0000 ]
   - type: SEG_LINETO
     pt1: [ 203.3768 ; 358.0000 ]
   - type: SEG_LINETO
     pt1: [ 203.3768 ; 10.0000 ]
   - type: SEG_LINETO
     pt1: [ 193.3768 ; 0.0000 ]
   - type: SEG_LINETO
     pt1: [ 0.0000 ; 0.0000 ]
  stroke: 0.0-0.0-0.5
  shadow: 0
  color: ff181818
  backcolor: fffeffdd

PATH:
   - type: SEG_MOVETO
     pt1: [ 193.3768 ; 0.0000 ]
   - type: SEG_LINETO
     pt1: [ 193.3768 ; 10.0000 ]
   - type: SEG_LINETO
     pt1: [ 203.3768 ; 10.0000 ]
   - type: SEG_LINETO
     pt1: [ 193.3768 ; 0.0000 ]
  stroke: 0.0-0.0-0.5
  shadow: 0
  color: ff181818
  backcolor: fffeffdd

TEXT:
  text: A Long
  position: [ 234.3794 ; 90.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: Long 
  position: [ 234.3794 ; 103.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: Long 
  position: [ 234.3794 ; 116.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: Long 
  position: [ 234.3794 ; 129.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: Long 
  position: [ 234.3794 ; 142.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: Long 
  position: [ 234.3794 ; 155.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: Long 
  position: [ 234.3794 ; 168.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: Long 
  position: [ 234.3794 ; 181.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: Long 
  position: [ 234.3794 ; 194.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: Long 
  position: [ 234.3794 ; 207.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: Long 
  position: [ 234.3794 ; 220.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: Long 
  position: [ 234.3794 ; 233.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: Long 
  position: [ 234.3794 ; 246.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: Long note
  position: [ 234.3794 ; 259.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: This 
  position: [ 234.3794 ; 272.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: note 
  position: [ 234.3794 ; 285.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: is on 
  position: [ 234.3794 ; 298.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: several
  position: [ 234.3794 ; 311.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: lines
  position: [ 234.3794 ; 324.6111 ]
  orientation: 0
  font: SansSerif.italic/13 [ITALIC]
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text:  
  position: [ 315.7608 ; 324.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: and can
  position: [ 234.3794 ; 337.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: contain 
  position: [ 234.3794 ; 350.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: HTML
  position: [ 321.5906 ; 350.6111 ]
  orientation: 0
  font: SansSerif.bold/13 [BOLD]
  color: ff000000
  extendedColor: NULL_COLOR

LINE:
  pt1: [ 228.3794 ; 358.5000 ]
  pt2: [ 431.7562 ; 358.5000 ]
  stroke: 0.0-0.0-1.0
  shadow: 0
  color: ff181818

LINE:
  pt1: [ 228.3794 ; 360.5000 ]
  pt2: [ 431.7562 ; 360.5000 ]
  stroke: 0.0-0.0-1.0
  shadow: 0
  color: ff181818

ELLIPSE:
  pt1: [ 237.3794 ; 366.5000 ]
  pt2: [ 242.3794 ; 371.5000 ]
  start: 0.0
  extend: 0.0
  stroke: 0.0-0.0-0.0
  shadow: 0
  color: ff000000
  backcolor: ff000000

TEXT:
  text: Calling 
  position: [ 246.8146 ; 373.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: the 
  position: [ 246.8146 ; 386.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: method 
  position: [ 246.8146 ; 399.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: foo()
  position: [ 342.9676 ; 399.6111 ]
  orientation: 0
  font: Monospaced.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text:  is 
  position: [ 246.8146 ; 412.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: prohibited
  position: [ 304.4687 ; 412.6111 ]
  orientation: 0
  font: SansSerif.plain/13 [BACKCOLOR]
  color: ff000000
  extendedColor: ffff0000

TEXT:
  text: overlap
  position: [ 246.8146 ; 425.6111 ]
  orientation: 0
  font: SansSerif.plain/13 [BACKCOLOR]
  color: ff000000
  extendedColor: ffff0000

RECTANGLE:
  pt1: [ 143.4243 ; 238.5000 ]
  pt2: [ 218.3794 ; 270.5000 ]
  xCorner: 25
  yCorner: 25
  stroke: 0.0-0.0-0.5
  shadow: 0
  color: ff181818
  backcolor: fff1f1f1

TEXT:
  text: foo1
  position: [ 153.4243 ; 257.8333 ]
  orientation: 0
  font: SansSerif.plain/12 []
  color: ff000000
  extendedColor: NULL_COLOR

EMPTY:
  pt1: [ 10.0000 ; 12.5000 ]
  pt2: [ 20.0000 ; 13.5000 ]

LINE:
  pt1: [ 15.0000 ; 12.5000 ]
  pt2: [ 15.0000 ; 879.5000 ]
  stroke: 0.0-0.0-1.5
  shadow: 0
  color: ff000000

PATH:
   - type: SEG_MOVETO
     pt1: [ 0.0000 ; 0.0000 ]
   - type: SEG_LINETO
     pt1: [ 0.0000 ; 188.0000 ]
   - type: SEG_LINETO
     pt1: [ -20.0000 ; 192.0000 ]
   - type: SEG_LINETO
     pt1: [ 0.0000 ; 196.0000 ]
   - type: SEG_LINETO
     pt1: [ 0.0000 ; 384.0000 ]
   - type: SEG_ARCTO
     radius: [ 0.0000 ; 0.0000 ]
     angle: 0.0
     largeArcFlag: false
     sweepFlag: false
     dest: [ 0.0000 ; 384.0000 ]
   - type: SEG_LINETO
     pt1: [ 185.8127 ; 384.0000 ]
   - type: SEG_ARCTO
     radius: [ 0.0000 ; 0.0000 ]
     angle: 0.0
     largeArcFlag: false
     sweepFlag: false
     dest: [ 185.8127 ; 384.0000 ]
   - type: SEG_LINETO
     pt1: [ 185.8127 ; 10.0000 ]
   - type: SEG_LINETO
     pt1: [ 175.8127 ; 0.0000 ]
   - type: SEG_LINETO
     pt1: [ 0.0000 ; 0.0000 ]
   - type: SEG_ARCTO
     radius: [ 0.0000 ; 0.0000 ]
     angle: 0.0
     largeArcFlag: false
     sweepFlag: false
     dest: [ 0.0000 ; 0.0000 ]
  stroke: 0.0-0.0-0.5
  shadow: 0
  color: ff181818
  backcolor: fffeffdd

PATH:
   - type: SEG_MOVETO
     pt1: [ 175.8127 ; 0.0000 ]
   - type: SEG_LINETO
     pt1: [ 175.8127 ; 10.0000 ]
   - type: SEG_LINETO
     pt1: [ 185.8127 ; 10.0000 ]
   - type: SEG_LINETO
     pt1: [ 175.8127 ; 0.0000 ]
  stroke: 0.0-0.0-0.5
  shadow: 0
  color: ff181818
  backcolor: fffeffdd

TEXT:
  text:  KO for 
  position: [ 553.7092 ; 468.6111 ]
  orientation: 0
  font: SansSerif.plain/13 [BACKCOLOR]
  color: ff000000
  extendedColor: ffff0000

TEXT:
  text: this note
  position: [ 553.7092 ; 481.6111 ]
  orientation: 0
  font: SansSerif.plain/13 [BACKCOLOR]
  color: ff000000
  extendedColor: ffff0000

TEXT:
  text: A Long
  position: [ 553.7092 ; 494.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: Long 
  position: [ 553.7092 ; 507.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: Long 
  position: [ 553.7092 ; 520.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: Long 
  position: [ 553.7092 ; 533.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: Long 
  position: [ 553.7092 ; 546.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: Long 
  position: [ 553.7092 ; 559.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: Long 
  position: [ 553.7092 ; 572.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: Long 
  position: [ 553.7092 ; 585.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: Long 
  position: [ 553.7092 ; 598.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: Long 
  position: [ 553.7092 ; 611.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: Long 
  position: [ 553.7092 ; 624.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: Long 
  position: [ 553.7092 ; 637.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: Long 
  position: [ 553.7092 ; 650.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: Long note
  position: [ 553.7092 ; 663.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: This 
  position: [ 553.7092 ; 676.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: note 
  position: [ 553.7092 ; 689.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: is on 
  position: [ 553.7092 ; 702.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: several
  position: [ 553.7092 ; 715.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: lines
  position: [ 553.7092 ; 728.6111 ]
  orientation: 0
  font: SansSerif.italic/13 [ITALIC]
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text:  
  position: [ 635.0906 ; 728.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: and can
  position: [ 553.7092 ; 741.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: contain 
  position: [ 553.7092 ; 754.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: HTML
  position: [ 640.9204 ; 754.6111 ]
  orientation: 0
  font: SansSerif.bold/13 [BOLD]
  color: ff000000
  extendedColor: NULL_COLOR

LINE:
  pt1: [ 547.7092 ; 762.5000 ]
  pt2: [ 733.5219 ; 762.5000 ]
  stroke: 0.0-0.0-1.0
  shadow: 0
  color: ff181818

LINE:
  pt1: [ 547.7092 ; 764.5000 ]
  pt2: [ 733.5219 ; 764.5000 ]
  stroke: 0.0-0.0-1.0
  shadow: 0
  color: ff181818

ELLIPSE:
  pt1: [ 556.7092 ; 770.5000 ]
  pt2: [ 561.7092 ; 775.5000 ]
  start: 0.0
  extend: 0.0
  stroke: 0.0-0.0-0.0
  shadow: 0
  color: ff000000
  backcolor: ff000000

TEXT:
  text: Calling 
  position: [ 566.1444 ; 777.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: the 
  position: [ 566.1444 ; 790.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: method 
  position: [ 566.1444 ; 803.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: foo()
  position: [ 662.2974 ; 803.6111 ]
  orientation: 0
  font: Monospaced.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text:  is 
  position: [ 566.1444 ; 816.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: prohibited
  position: [ 566.1444 ; 829.6111 ]
  orientation: 0
  font: SansSerif.plain/13 []
  color: ff000000
  extendedColor: NULL_COLOR

RECTANGLE:
  pt1: [ 452.7562 ; 629.5000 ]
  pt2: [ 527.7092 ; 661.5000 ]
  xCorner: 25
  yCorner: 25
  stroke: 0.0-0.0-0.5
  shadow: 0
  color: ff181818
  backcolor: fff1f1f1

TEXT:
  text: foo2
  position: [ 462.7562 ; 648.8333 ]
  orientation: 0
  font: SansSerif.plain/12 []
  color: ff000000
  extendedColor: NULL_COLOR

ELLIPSE:
  pt1: [ 479.2327 ; 857.5000 ]
  pt2: [ 501.2327 ; 879.5000 ]
  start: 0.0
  extend: 0.0
  stroke: 0.0-0.0-1.0
  shadow: 0
  color: ff222222
  backcolor: NULL_COLOR

ELLIPSE:
  pt1: [ 484.2327 ; 862.5000 ]
  pt2: [ 496.2327 ; 874.5000 ]
  start: 0.0
  extend: 0.0
  stroke: 0.0-0.0-1.0
  shadow: 0
  color: middle(ff222222 & ff222222 )
  backcolor: ff222222

EMPTY:
  pt1: [ 441.7562 ; 12.5000 ]
  pt2: [ 451.7562 ; 13.5000 ]

LINE:
  pt1: [ 446.7562 ; 12.5000 ]
  pt2: [ 446.7562 ; 879.5000 ]
  stroke: 0.0-0.0-1.5
  shadow: 0
  color: ff000000

EMPTY:
  pt1: [ 733.5219 ; 12.5000 ]
  pt2: [ 752.0498 ; 13.5000 ]

LINE:
  pt1: [ 738.5219 ; 12.5000 ]
  pt2: [ 738.5219 ; 879.5000 ]
  stroke: 0.0-0.0-1.5
  shadow: 0
  color: ff000000

LINE:
  pt1: [ 180.9019 ; 55.5000 ]
  pt2: [ 180.9019 ; 238.5000 ]
  stroke: 0.0-0.0-1.0
  shadow: 0
  color: ff181818

POLYGON:
  points:
   - [ 176.9019 ; 228.5000 ]
   - [ 180.9019 ; 238.5000 ]
   - [ 184.9019 ; 228.5000 ]
   - [ 180.9019 ; 232.5000 ]
  stroke: 0.0-0.0-1.0
  shadow: 0
  color: ff181818
  backcolor: ff181818

LINE:
  pt1: [ 490.2327 ; 661.5000 ]
  pt2: [ 490.2327 ; 857.5000 ]
  stroke: 0.0-0.0-1.0
  shadow: 0
  color: ff181818

POLYGON:
  points:
   - [ 486.2327 ; 847.5000 ]
   - [ 490.2327 ; 857.5000 ]
   - [ 494.2327 ; 847.5000 ]
   - [ 490.2327 ; 851.5000 ]
  stroke: 0.0-0.0-1.0
  shadow: 0
  color: ff181818
  backcolor: ff181818

LINE:
  pt1: [ 180.9019 ; 270.5000 ]
  pt2: [ 180.9019 ; 448.5000 ]
  stroke: 0.0-0.0-1.0
  shadow: 0
  color: ff181818

LINE:
  pt1: [ 180.9019 ; 448.5000 ]
  pt2: [ 490.2327 ; 448.5000 ]
  stroke: 0.0-0.0-1.0
  shadow: 0
  color: ff181818

LINE:
  pt1: [ 490.2327 ; 448.5000 ]
  pt2: [ 490.2327 ; 629.5000 ]
  stroke: 0.0-0.0-1.0
  shadow: 0
  color: ff181818

POLYGON:
  points:
   - [ 486.2327 ; 619.5000 ]
   - [ 490.2327 ; 629.5000 ]
   - [ 494.2327 ; 619.5000 ]
   - [ 490.2327 ; 623.5000 ]
  stroke: 0.0-0.0-1.0
  shadow: 0
  color: ff181818
  backcolor: ff181818

TEXT:
  text: Actor 1
  position: [ 163.2884 ; 26.5000 ]
  orientation: 0
  font: SansSerif.plain/18 []
  color: ff000000
  extendedColor: NULL_COLOR

TEXT:
  text: Actor 2
  position: [ 525.0409 ; 26.5000 ]
  orientation: 0
  font: SansSerif.plain/18 []
  color: ff000000
  extendedColor: NULL_COLOR

"""
*/